@@ -1,7 +1,6 @@
 
 from datetime import datetime
 import os, re, traceback, sys
-import papermill as pm
 import pandas as pd
 from py_topping.general_use import email_sender
 
@@ -19,20 +18,21 @@ def run_script(script_list , out_folder = '', out_prefix = None): #, email_sende
     log_out.append(str(datetime.now()).split('.')[0])
     log_out.append(i)
     try :
-        if i.split('.')[-1] == 'ipynb' : 
+        if i.endswith('.ipynb') : 
+            import papermill as pm
             if out_prefix == None : prefix = datetime.now().strftime('%Y_%m_%d_%H_%M_')
             else : prefix = out_prefix
             out_name = str(out_folder) + '/' + prefix + i.split('\\')[-1].split('/')[-1]
             log_out.append(out_name)
             pm.execute_notebook(i,out_name)
-        elif i.split('.')[-1] == 'py' :
+        elif i.endswith('.py') :
             log_out.append(None)
             if len(re.findall(re_pattern, i )) > 0 :
                 print("Script File {} has {} in the name, Will EXECUTE with UNSAFE method".format(i,re_pattern))
                 with open(i, encoding="utf8",newline='') as f :
                     exec(f.read())
             else : 
-                i_ = i.replace('.py','')
+                i_ = i[:-3]
                 if i_[0] == '/' : i_ = i_[1:]
                 for j in ['/','\\'] : i_ = i_.replace(j , '.')
                 exec('import {}'.format(i_))
@@ -50,7 +50,8 @@ def run_script(script_list , out_folder = '', out_prefix = None): #, email_sende
   return pd.DataFrame(logs_out, columns = ['start','script','notebook_out','run_result','end'])
 
 def run_pipeline(script_list = [], out_folder = '', out_prefix = None, email_dict = None , sending = False
-                    , only_error = False, notebook_attached = False, attached_only_error = False, attached_log = False, log_sql = None) :
+                    , only_error = False, notebook_attached = False, attached_only_error = False, attached_log = False, log_sql = None
+                    , line_sending = None, line_subject = 'Untitled') :
 
     if sending :
         if (['user' , 'password', 'server' ,'sendto','subject'].sort() != list(email_dict.keys()).sort()) or (email_dict == None) :
@@ -68,8 +69,10 @@ def run_pipeline(script_list = [], out_folder = '', out_prefix = None, email_dic
         run_log.astype('str').to_sql(log_sql['table_name'], con = log_sql['da_tran_SQL'].engine , if_exists = 'append', index = False)
         run_log = run_log.drop(['job_name'], axis = 1)
 
-    if sending & only_error  : 
-        if (run_log['run_result'] != 'OK').sum() == 0 : sending = False
+    if ((line_sending != None) | sending) & only_error  : 
+        if (run_log['run_result'] != 'OK').sum() == 0 : 
+            sending = False
+            line_sending = None
         else : run_log = run_log[(run_log['run_result'] != 'OK')]
 
     if sending & notebook_attached : 
@@ -96,4 +99,12 @@ def run_pipeline(script_list = [], out_folder = '', out_prefix = None, email_dic
 
     if sending & attached_log : os.remove(file_name)
 
+    if line_sending != None :
+        for i in run_log.index :
+            line_out_log = run_log.drop('notebook_out', axis = 1).T[i].to_string()
+            line_out_log = '\n-----\n{}\n-----\n{}'.format(line_subject,line_out_log)
+            line_sending.send(line_out_log , notification = True)
+            if run_log.loc[i,'run_result'] != 'OK' : 
+                line_sending.send(str(run_log.loc[i,'run_result']) , notification = True)
+
     return out_log  
\ No newline at end of file
